@@ -1,4 +1,3 @@
-"""minos.common.configuration.config module."""
 from __future__ import (
     annotations,
 )
@@ -13,7 +12,6 @@ from pathlib import (
 )
 from typing import (
     Any,
-    NoReturn,
     Union,
 )
 
@@ -35,7 +33,7 @@ SAGA = namedtuple("Saga", "storage")
 REST = namedtuple("Rest", "host port")
 REPOSITORY = namedtuple("Repository", "database user password host port")
 SNAPSHOT = namedtuple("Snapshot", "database user password host port")
-DISCOVERY = namedtuple("Discovery", "host port")
+DISCOVERY = namedtuple("Discovery", "client host port")
 
 _ENVIRONMENT_MAPPER = {
     "service.name": "MINOS_SERVICE_NAME",
@@ -61,6 +59,7 @@ _ENVIRONMENT_MAPPER = {
     "snapshot.database": "MINOS_SNAPSHOT_DATABASE",
     "snapshot.user": "MINOS_SNAPSHOT_USER",
     "snapshot.password": "MINOS_SNAPSHOT_PASSWORD",
+    "discovery.client": "MINOS_DISCOVERY_CLIENT",
     "discovery.host": "MINOS_DISCOVERY_HOST",
     "discovery.port": "MINOS_DISCOVERY_PORT",
 }
@@ -91,6 +90,7 @@ _PARAMETERIZED_MAPPER = {
     "snapshot.database": "snapshot_database",
     "snapshot.user": "snapshot_user",
     "snapshot.password": "snapshot_password",
+    "discovery.client": "minos_discovery_client",
     "discovery.host": "minos_discovery_host",
     "discovery.port": "minos_discovery_port",
 }
@@ -138,7 +138,7 @@ class MinosConfig(MinosConfigAbstract):
         self._with_environment = with_environment
         self._parameterized = kwargs
 
-    def _load(self, path: Path) -> NoReturn:
+    def _load(self, path: Path) -> None:
         if not path.exists():
             raise MinosConfigException(f"Check if this path: {path} is correct")
 
@@ -300,6 +300,7 @@ class MinosConfig(MinosConfigAbstract):
 
         :return: A ``DISCOVERY`` NamedTuple instance.
         """
+        client = self._get("discovery.client")
         host = self._get("discovery.host")
         port = self._get("discovery.port")
-        return DISCOVERY(host=host, port=port)
+        return DISCOVERY(client=client, host=host, port=port)
