@@ -1,11 +1,3 @@
-"""
-Copyright (C) 2021 Clariteia SL
-
-This file is part of minos framework.
-
-Minos framework can not be copied and/or distributed without the express permission of Clariteia SL.
-"""
-
 from __future__ import (
     annotations,
 )
@@ -14,7 +6,6 @@ from asyncio import (
     gather,
 )
 from typing import (
-    NoReturn,
     Type,
     Union,
 )
@@ -66,7 +57,7 @@ class DependencyInjector:
 
         return injections
 
-    async def wire(self, *args, **kwargs) -> NoReturn:
+    async def wire(self, *args, **kwargs) -> None:
         """Connect the configuration.
 
         :return: This method does not return anything.
@@ -75,7 +66,7 @@ class DependencyInjector:
 
         await gather(*(injection.setup() for injection in self.injections.values()))
 
-    async def unwire(self) -> NoReturn:
+    async def unwire(self) -> None:
         """Disconnect the configuration.
 
         :return: This method does not return anything.
