@@ -1,14 +1,3 @@
-"""
-Copyright (C) 2021 Clariteia SL
-
-This file is part of minos framework.
-
-Minos framework can not be copied and/or distributed without the express permission of Clariteia SL.
-"""
-from typing import (
-    NoReturn,
-)
-
 from ...database import (
     PostgreSqlMinosDatabase,
 )
@@ -17,9 +6,9 @@ from ...database import (
 class PostgreSqlSnapshotSetup(PostgreSqlMinosDatabase):
     """Minos Snapshot Setup Class"""
 
-    async def _setup(self) -> NoReturn:
+    async def _setup(self) -> None:
         await self.submit_query(_CREATE_TABLE_QUERY, lock=hash("snapshot"))
-        await self.submit_query(_CREATE_OFFSET_TABLE_QUERY, lock=hash("snapshot"))
+        await self.submit_query(_CREATE_OFFSET_TABLE_QUERY, lock=hash("snapshot_aux_offset"))
 
 
 _CREATE_TABLE_QUERY = """
@@ -27,7 +16,8 @@ CREATE TABLE IF NOT EXISTS snapshot (
     aggregate_uuid UUID NOT NULL,
     aggregate_name TEXT NOT NULL,
     version INT NOT NULL,
-    data BYTEA,
+    schema BYTEA,
+    data JSONB,
     created_at TIMESTAMPTZ NOT NULL DEFAULT NOW(),
     updated_at TIMESTAMPTZ NOT NULL DEFAULT NOW(),
     PRIMARY KEY (aggregate_uuid, aggregate_name)
